import { useEffect, useMemo } from "react";
import { atom as $, useAtom, Atom, PrimitiveAtom, useAtomValue, useSetAtom, } from 'jotai';

type PickerInput = { 
  $options?:PrimitiveAtom<Array<string>>, 
  $isLoading?:PrimitiveAtom<boolean>, 
  $selectedOption?:PrimitiveAtom<string>, 
  $url:Atom<string>, 
  $isEnabled?:Atom<boolean>
};
export function Picker({ 
    $url, 
    $options        = useMemo(()=>$([]),  []), 
    $isLoading      = useMemo(()=>$(true),[]), 
    $isEnabled      = useMemo(()=>$(true),[]), 
    $selectedOption = useMemo(()=>$(''),  [])
  }: PickerInput){
  const url = useAtomValue($url);
  const options = useAtomValue($options);
  const isLoading = useAtomValue($isLoading);
  const [selectedOption, setSelectedOption] = useAtom($selectedOption);
  const isEnabled = useAtomValue($isEnabled);

  const optionsFetched = useSetAtom(useMemo(()=>$(null, (get,set,options)=>{
    set($options, options);
    set($isLoading, false);
  }),[$options, $isLoading]));

  useEffect(()=>{
    if(isEnabled){
      fetch(url)
      .then(x=>x.json())
      .catch((err)=>['AAPL', 'MSFT', 'GOOG'])
      .then(optionsFetched)
    }
  },[url, isEnabled])
  
  return (
    <div>
      {isLoading
      ?
      <span>Loading...</span>
      :
      <select value={selectedOption} onChange={(e)=>{ setSelectedOption(e.target.value); }}>
        <option key="" value=""></option>
        {options.map((date)=>
          <option key={date} value={date}>{date}</option>
        )}
      </select>
      }
    </div>
  );
}